import os
import sqlite3
from flask import Flask, redirect, request, render_template, jsonify

app = Flask(__name__)
DATABASE = "project_db.db"

ALLOWED_EXTENSIONS = set(['txt', 'pdf', 'png', 'jpg', 'jpeg', 'gif'])

#Error handling for common database connection.
#Parameter optional. Defaults to DATABASE.
def connect_db(db_file=DATABASE):
    conn = None
    try:
        conn = sqlite3.connect(db_file)
    except:
        print("Error connecting to database.")
    return conn

@app.route("/", methods=['GET'])
def returnIndex():
    if (request.method == 'GET'):
        return render_template("test.html")

@app.route("/Manage_Coworking_Spaces", methods=['GET'])
def returnManageCoworkingSpaces():
    if (request.method == 'GET'):
        return render_template("Manage_Coworking_Spaces.html")

@app.route("/SearchRecord", methods=['POST', 'GET'])
def searchRecord():

    if (request.method =='POST'):
        recordName = request.form.get('recordName', default="Error")
        print(f"Searching for '{recordName}' in the database.")

        try:
            conn = connect_db()
            cur = conn.cursor()
            cur.execute("SELECT * FROM coworking_spaces WHERE Name=?;", [recordName])
            recordData = cur.fetchall()

        except:
            print(f"Encountered an error whilst searching for record.")

        finally:
            conn.close()

            if not recordData: #If recordData is an empty list...
                print(f"'{recordName}' not found.")
                return (f"'{recordName}' not found.")

            else:
                print(f"Found: {recordData}")
                return (recordData)

@app.route('/AddRecord', methods=['POST'])
def addRecord():

    if (request.method == 'POST'):
        recordName = request.form.get('recordName', default="Error")
        recordAddress = request.form.get('recordAddress', default="Error")
        recordMainPhotos = request.form.get('recordMainPhotos', default="Error")
        recordAdditionalPhotos = request.form.get('recordAdditionalPhotos', default="Error")
        recordDescription = request.form.get('recordDescription', default="Error")
        recordWebsite = request.form.get('recordWebsite', default="Error")
        recordEmail = request.form.get('recordEmail', default="Error")
        recordPhoneNumber = request.form.get('recordPhoneNumber', default="Error")
        recordOpeningHours = request.form.get('recordOpeningHours', default="Error")
        recordCheckinInstructions = request.form.get('recordCheckinInstructions', default="Error")
        recordData = [recordName, recordAddress, recordMainPhotos, recordAdditionalPhotos, recordDescription, recordWebsite, recordEmail, recordPhoneNumber, recordOpeningHours, recordCheckinInstructions]
        print(f"Adding '{recordName}' to the database.")

        try:
            conn = connect_db()
            cur = conn.cursor()
            cur.execute("INSERT INTO coworking_spaces ('Name', 'Address', 'Main_Photo', 'Additional_Photos', 'Description', 'Website', 'Email', 'Phone_Number', 'Opening_Hours', 'Checkin_Instructions')\
                        VALUES (?,?,?,?,?,?,?,?,?,?)", (recordName, recordAddress, recordMainPhotos, recordAdditionalPhotos, recordDescription, recordWebsite, recordEmail, recordPhoneNumber, recordOpeningHours, recordCheckinInstructions))
            conn.commit()
            infoMessage = (f"Added: {recordData}")

        except:
            conn.rollback()
            infoMessage = (f"Error adding record.")

        finally:
            conn.close()
            print(infoMessage)
            return (infoMessage)

@app.route('/DeleteRecord', methods=['POST'])
def deleteRecord():

    if (request.method =='POST'):
        recordName = request.form.get('recordName', default="Error")
        print(f"Deleting '{recordName}' from the database.")

        try:
            conn = sqlite3.connect(DATABASE)
            cur = conn.cursor()
            cur.execute("DELETE FROM coworking_spaces WHERE Name=?;", [recordName])
            conn.commit()
            infoMessage = (f"Deleted: '{recordName}'.")

        except:
            conn.rollback()
            infoMessage = (f"Error deleting record.")

        finally:
            conn.close()
            print(infoMessage)
            return (infoMessage)

@app.route('/UpdateRecord', methods=['POST'])
def updateRecord():

    if (request.method == 'POST'):
        recordName = request.form.get('recordName', default="Error")
        recordAddress = request.form.get('recordAddress', default="Error")
        recordMainPhotos = request.form.get('recordMainPhotos', default="Error")
        recordAdditionalPhotos = request.form.get('recordAdditionalPhotos', default="Error")
        recordDescription = request.form.get('recordDescription', default="Error")
        recordWebsite = request.form.get('recordWebsite', default="Error")
        recordEmail = request.form.get('recordEmail', default="Error")
        recordPhoneNumber = request.form.get('recordPhoneNumber', default="Error")
        recordOpeningHours = request.form.get('recordOpeningHours', default="Error")
        recordCheckinInstructions = request.form.get('recordCheckinInstructions', default="Error")
        recordData = [recordName, recordAddress, recordMainPhotos, recordAdditionalPhotos, recordDescription, recordWebsite, recordEmail, recordPhoneNumber, recordOpeningHours, recordCheckinInstructions]
        print(f"Updating '{recordName}' in the database.")

        try:
            conn = sqlite3.connect(DATABASE)
            cur = conn.cursor()
            cur.execute("UPDATE coworking_spaces SET 'Name' = ?, 'Address' = ?, 'Main_Photo' = ?, 'Additional_Photos' = ?, 'Description' = ?, 'Website' = ?, 'Email' = ?, 'Phone_Number' = ?, 'Opening_Hours' = ?, 'Checkin_Instructions' = ? WHERE Name=?;", [recordName, recordAddress, recordMainPhotos, recordAdditionalPhotos, recordDescription, recordWebsite, recordEmail, recordPhoneNumber, recordOpeningHours, recordCheckinInstructions, recordName])
            conn.commit()
            infoMessage = (f"Updated: '{recordName}'.")

        except:
            conn.rollback()
            infoMessage = (f"Error updating record.")

        finally:
            conn.close()
            print(infoMessage)
            return (infoMessage)

if __name__ == "__main__":
    app.run(debug=True)
